Conway's Game of Life
=====================

Simple pygame implementation of Conway's Game of Life.

Installation
------------

Install with pip::

  pip install pygameoflife

Install from source::

  python setup.py install


Running
-------

Run via launch script installed with pip package::

  pygameoflife

Run as a Python module::

  python -m pygameoflife

Using inside of code
--------------------

To import the class in to your own code::

  from pygameoflife.LifeGame import LifeGame
  LifeGame().run()


Controls
--------

There are a couple keybinds available:

- q - Quit
- s - Start/stop (toggle pause)
- r - Randomize the grid

Contact
-------

NanoDano <nanodano@devdungeon.com>

